@@ -51,9 +51,4 @@ class parser:
                 print(f'Предметов в словарь: {str(len(self.items))}')
             except:
                 print("Все предметы в словаре")
-                break
-
-
-if __name__ == "__main__":
-    obj = parser()
-    obj.csmoney()
+                break
\ No newline at end of file
